@@ -1,10 +1,35 @@
 # -*- coding: utf-8 -*-
+"""
+    SmartHTTP 
+    Release 0.4 rev. 123 on 2010-04-14 09:33:33.212723
+    Copyright (C) Thu Aug 27 04:01:12 2009 +1100-Wed Apr 14 20:33:28 2010 +1100,
+    Authors: Dan Kluev <dan@kluev.name>
+
+    Module smarthttp.sites
+    Base classes for site handlers
+    Last changed on Wed Apr 14 14:50:37 2010 +1100 rev. 111:5efdacc70dde by Dan Kluev <orion@ssorion.info>
+
+    This program is free software: you can redistribute it and/or modify
+    it under the terms of the GNU General Public License as published by
+    the Free Software Foundation, either version 3 of the License, or
+    (at your option) any later version.
+
+    This program is distributed in the hope that it will be useful,
+    but WITHOUT ANY WARRANTY; without even the implied warranty of
+    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+    GNU General Public License for more details.
+
+    You should have received a copy of the GNU General Public License
+    along with this program.  If not, see <http://www.gnu.org/licenses/>.
+"""
 from smarthttp.client import HTTPClient
 import urllib, time
 from urlparse import urlparse
 from datetime import datetime
 from decorator import decorator
-from .exceptions import ParseException, XPathException, HTTPException, HTMLException
+from .exceptions import ParseException, XPathException, HTTPException, HTMLException, KeyException
+from smarthttp.lib.containers import SmartDict, strdict
+from smarthttp.lib.maps import SmartMap, LocalMap
 import logging
 
 class SiteFunctionResult(object):
@@ -40,6 +65,8 @@ class HTTPSite(object):
     last_request = None
     base_path = None
     domain = None
+    port   = 80
+    map    = SmartMap()
     def __init__(self, client=None, log=None, delay=0, **kw):
         self.delay = delay
         if not client and not log:
@@ -68,13 +95,22 @@ class HTTPSite(object):
                     else:
                         sp = '?'
                     url = "%s%s%s=%s" % (url, sp, param, urllib.quote(value))
+        if self.port != 80:
+            port = ':{0.port}'.format(self)
+        else:
+            port = ''
+        if type(url) == unicode:
+            url = url.encode('utf-8')
         if not '://' in url:
             if url[0] != '/':
                 url = "/%s" % url
             if self.base_path:
-                url = "%s%s" % (self.base_path, url)
-            url = "%s://%s%s" % (self.proto, self.domain, url)
+                url = "{0}{1}".format(self.base_path, url)
+            url = "{0.proto}://{0.domain}{1}{2}".format(self, port, url)
         return url
+        
+    def url(self, url, params=None, **kw):
+        return self.map.url(url, params, **kw)
 
     def request(self, url, **kw):
         if self.domain:
@@ -139,20 +175,35 @@ class HTTPSite(object):
         res = self.assertXPath(node, path, 1, True)
         return res[0]
 
+    def assertKey(self, d, k):
+        """
+        Assert that dict has needed key and return the value
+        >>> HTTPSite().assertKey({'a':1, 'b':2}, 'a')
+        1
+        """
+        if k in d:
+            return d[k]
+        else:
+            raise KeyException(u"Key {0} is missing.".format(k))
 
     def __repr__(self):
         return "<Site[{0.__class__.__name__}] @ {0.proto} {0.domain} {0.base_path}>".format(self)
 
 class SpecificSite(HTTPSite):
-    pass
+    def __init__(self, *args, **kw):
+        HTTPSite.__init__(self, *args, **kw)
+        if self.__class__.map:
+            self.map = LocalMap(site=self, _map=self.__class__.map)
+
 
 class SiteEngine(HTTPSite):
-    def __init__(self, client=None, log=None, domain=None, base_path=None, url=None, *args, **kw):
+    def __init__(self, client=None, log=None, domain=None, port=80, base_path=None, url=None, *args, **kw):
         HTTPSite.__init__(self, client=client, log=log, *args, **kw)
         if url:
             urlp = urlparse(url)
             domain = urlp.hostname or domain
             base_path = urlp.path or base_path
+            self.port = urlp.port or port
         self.domain = domain
         if base_path:
             if base_path[0] != '/':
@@ -160,7 +211,9 @@ class SiteEngine(HTTPSite):
             if base_path[-1] == '/':
                 base_path = base_path[:-1]
         self.base_path = base_path
-
+        if self.__class__.map:
+            self.map = LocalMap(site=self, _map=self.__class__.map)
+	
 @decorator    
 def parser(func, self, *args, **kw):
     """
