@@ -1,15 +1,32 @@
 # -*- coding: utf-8 -*-
 """
-Module for imageboard engines
+    SmartHTTP 
+    Release 0.4 rev. 123 on 2010-04-14 09:33:33.212723
+    Copyright (C) Thu Aug 27 04:01:12 2009 +1100-Wed Apr 14 20:33:28 2010 +1100,
+    Authors: Dan Kluev <dan@kluev.name>
+
+    Module smarthttp.sites.imageboards
+    Collection of handlers for imageboard engines and sites.
+    Last changed on Wed Apr 14 15:08:41 2010 +1100 rev. 113:a476934e9a6d by Dan Kluev <orion@ssorion.info>
+
+    This program is free software: you can redistribute it and/or modify
+    it under the terms of the GNU General Public License as published by
+    the Free Software Foundation, either version 3 of the License, or
+    (at your option) any later version.
+
+    This program is distributed in the hope that it will be useful,
+    but WITHOUT ANY WARRANTY; without even the implied warranty of
+    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+    GNU General Public License for more details.
+
+    You should have received a copy of the GNU General Public License
+    along with this program.  If not, see <http://www.gnu.org/licenses/>.
 """
-from smarthttp.lib.containers import SmartDict, strdict
-from smarthttp.sites import SpecificSite, SiteEngine, parser
-from datetime import datetime
+from smarthttp.sites import *
 
 class Imageboard(SiteEngine):
     pass
 
-
 class Board(object):
     name = None
     site = None
