@@ -2,7 +2,7 @@
 """
 """
 from smarthttp.sites import SpecificSite
-from smarthttp.dom import GetPlainText, GetDOM, ForcedEncoding
+from smarthttp.html import GetPlainText, GetDOM, ForcedEncoding
 import re, datetime
 
 class UdaffCom(SpecificSite):
